gas: sframe: improve code comments around SFRAME_FRE_BASE_REG_INVAL

Rename it to SFRAME_FRE_REG_INVALID.

gas/
        * gen-sframe.c (sframe_row_entry_new): Adjust code comments a
	bit.
        * gen-sframe.h (SFRAME_FRE_BASE_REG_INVAL): Rename from..
        (SFRAME_FRE_REG_INVALID): ..to this.
diff --git a/gas/gen-sframe.h b/gas/gen-sframe.h
index cf9f598..d5cad32 100644
--- a/gas/gen-sframe.h
+++ b/gas/gen-sframe.h
@@ -34,7 +34,8 @@
 #define SFRAME_FRE_ELEM_LOC_REG		0
 #define SFRAME_FRE_ELEM_LOC_STACK	1
 
-#define SFRAME_FRE_BASE_REG_INVAL	((unsigned int)-1)
+/* An invalid register number.  */
+#define SFRAME_FRE_REG_INVALID		((unsigned int)-1)
 
 /* SFrame Frame Row Entry (FRE).
diff --git a/gas/gen-sframe.c b/gas/gen-sframe.c
index b1aa807..3ac1cf4 100644
--- a/gas/gen-sframe.c
+++ b/gas/gen-sframe.c
@@ -504,9 +504,9 @@
 sframe_row_entry_new (void)
 {
   struct sframe_row_entry *fre = XCNEW (struct sframe_row_entry);
-  /* Reset cfa_base_reg to -1.  A value of 0 will imply some valid register
-     for the supported arches.  */
-  fre->cfa_base_reg = SFRAME_FRE_BASE_REG_INVAL;
+  /* Reset cfa_base_reg to SFRAME_FRE_REG_INVALID.  A value of 0 may imply a
+     valid register for a supported arch.  */
+  fre->cfa_base_reg = SFRAME_FRE_REG_INVALID;
   fre->merge_candidate = true;
   /* Reset the mangled RA status bit to zero by default.  We will
      initialize it in sframe_row_entry_initialize () with the sticky